AiClient class abstract

Implementers

Constructors

AiClient(AiConfig config)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage({required List<AiMessage> history, List<AiTool>? tools}) Future<AiMessage>
streamMessage({required List<AiMessage> history, List<AiTool>? tools}) Stream<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited